Changelog
=========

0.3.1
-----

* Fixed broken import in generated tests.py in apps

0.3.0
-----

* Corrected small error in test_settings.py comment
* Merged Fabio Corneti's django_buildout template and egg-info tidying (thanks Fabio!)
* Updated docs to note new template

0.2.1
-----

* Added missing opening parenthesis to urls.py template for django_app
* Renamed doc files to .rst, and updated MANIFEST accordingly

0.2.0
-----

* Added templates for namespaced projects and applications

0.1.2
-----

* Fixed egg build problem which omitted templates

0.1.1
-----

* Corrected setup.cfg release tagging

0.1
---

* Initial work on django_app and django_project templates

